@@ -1,7 +1,4 @@
-/* $XdotOrg: $ */
 /*
- * Id: render.c,v 1.2 1999/11/02 06:16:48 keithp Exp $
- *
  * Copyright 1999 SuSE, Inc.
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -18,12 +15,11 @@
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL SuSE
  * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
- * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
+ * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
  * Author:  Keith Packard, SuSE, Inc.
  */
-/* $XFree86: xc/lib/font/builtins/render.c,v 1.3 1999/12/30 02:29:51 robin Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -50,7 +46,7 @@ BuiltinOpenBitmap (FontPathElementPtr fpe, FontPtr *ppFont, int	flags,
     file = BuiltinFileOpen (fileName);
     if (!file)
 	return BadFontName;
-    pFont = (FontPtr) xalloc(sizeof(FontRec));
+    pFont = malloc(sizeof(FontRec));
     if (!pFont) {
 	BuiltinFileClose (file, 0);
 	return AllocError;
@@ -69,7 +65,7 @@ BuiltinOpenBitmap (FontPathElementPtr fpe, FontPtr *ppFont, int	flags,
 
     BuiltinFileClose (file, 0);
     if (ret != Successful)
-	xfree(pFont);
+	free(pFont);
     else
 	*ppFont = pFont;
     return ret;
